class JSONSchemaQuerySetMixin():
    def _setup(self):
        # find all JSONFieldMixin fields
        pass

    def _substitute_keys(self, keys):
        pass

    def filter(self):
        pass

    def order_by(self):
        pass



from importlib import import_module

import django
from django.conf import settings


def JSONField(*args, **kwargs):
    """
    Returns json field implementation depends on the
    default db connection type or `db_vendor` keyword argument
    """
    db_vendor = kwargs.pop('db_vendor', None)
    if db_vendor is None:
        backend = import_module('{}.base'.format(settings.DATABASES['default']['ENGINE']).replace('_psycopg2', ''))
        db_vendor = backend.DatabaseWrapper.vendor

    if db_vendor == 'postgresql':
        from django.contrib.postgres.fields import JSONField as PG_JSONField
        return PG_JSONField(*args, **kwargs)
    elif db_vendor == 'mysql':
        try:
            from django_mysql.models import JSONField as MY_JSONField
        except ImportError:
            raise ImportError("django-mysql isn't installed")
        else:
            return MY_JSONField(*args, **kwargs)
    elif db_vendor == 'oracle':
        try:
            from oracle_json_field.fields import JSONField as OR_JSONField
        except ImportError:
            raise ImportError("oracle-json-field isn't installed")
        else:
            return OR_JSONField(*args, **kwargs)
    else:
        if django.VERSION >= (3, 0):
            # Quick six for django-annoying
            import six
            from django import utils
            utils.six = six

        try:
            from annoying.fields import JSONField as DEFAULT_JSONField
        except ImportError:
            raise ImportError("django-annoying isn't installed")
        else:
            return DEFAULT_JSONField(*args, **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup


setup(
    name='django-jsonfield-schema',
    version='0.3.0',
    author='Mikhail Podgurskiy',
    author_email='kmmbvnr@gmail.com',
    description='Expose JSONField data as a virtual django model fields.',
    long_description=open('README.rst').read(),
    platforms=['Any'],
    keywords=['workflow', 'django', 'bpm', 'automaton'],
    url='http://github.com/viewflow/jsonfield-schema',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Framework :: Django',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.0',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
    ],
    install_requires=[
        'Django>=1.11',
        'six',
    ],
    packages=['jsonfield_schema'],
    include_package_data=True,
    zip_safe=False
)
